@@ -11,7 +11,7 @@ from commitcli.common import changes_choices_by_format, get_questions, get_prese
 
 from configmanager.config_manager import ConfigManager
 from configmanager.format_module_manager import ModuleConfig
-import pendulum
+from common.logger import logger
 
 class CommitMessage(object):
     """This clas is a abstraction of a commit message,
@@ -23,7 +23,6 @@ class CommitMessage(object):
     
     def __init__(
         self,
-        # format: str = "cc",
         module_manager: ModuleManager,
         configuration_manager: ConfigManager = ConfigManager(),
         tag: str = None,
@@ -44,6 +43,7 @@ class CommitMessage(object):
         super()
         self.tag = tag
         self.module = module
+        self.moduleid = None # module id only set when answer comes from preselected answers
         self.header = header
         self.body = body
         self.footer = footer
@@ -88,6 +88,7 @@ class CommitMessage(object):
             answers (dict): answers provided by the user
         """
         if answers:
+            # platform specific fixes
             if self.format == 'odoo':
                 self.tag = answers['tag']
                 self.module = answers['module']
@@ -105,6 +106,10 @@ class CommitMessage(object):
                     self.body = answers['body']
                 if 'footer' in answers:
                     self.footer = answers['footer']
+            
+            if 'moduleid' in answers.keys() and answers['moduleid'] :
+                logger.log("INFO", f"seting module id {answers['moduleid']}")
+                self.moduleid = answers['moduleid']
             return True
         else:
             return False
@@ -117,9 +122,11 @@ class CommitMessage(object):
         preselected_questions:list[PreselectedQuestion] = get_preselected_questions(format=self.format)
         
         for preselected_question in preselected_questions:
-            question = preselected_question.get_value(self.module_manager) 
-            if question :
-                preselected_answers.append(question)
+            # this calls a functions asigned to get_value
+            answer:dict = preselected_question.get_value(self.module_manager) 
+            if len(answer.keys()) > 0 :
+                for key in answer.keys():
+                    preselected_answers.append({ key: answer[key] })
         
         return preselected_answers
 
@@ -134,35 +141,35 @@ class CommitMessage(object):
 
         # if we had preselected result then we can get them here
         preselected_answers:list[dict] = self.get_preselected_answers()
+
         # ------ automatic answers segregation and formating ---------
         request_optionals:bool = True if self.config.get_config("avoid_optionals") else False 
         
         preselected_answers_key_list:list[str] = [ list(key.keys())[0] for key in preselected_answers ]
 
+        logger.log("INFO", preselected_answers)
+
+        logger.log("INFO", "=====================")
+
+        # -------------- speciaol changes --------------
         # ------ regular question prompting ------------
 
         normal_questions = get_questions(self.format, preselected_answers_key_list, request_optionals)
 
         normal_answers = inquirer.prompt(normal_questions[self.format])
         
-        # print(normal_answers, preselected_answers)
 
         answers:dict = dict()
         for preselected_answer in preselected_answers:
             answers.update(preselected_answer)
-        answers.update(normal_answers)
         
-        # print(answers)
+        logger.log("INFO", normal_answers)
 
+        answers.update(normal_answers)
+
+        logger.log("INFO", answers)
+        
         if answers:
-            # TODO: handle optional
-            # if self.format in self.optional_questions and not request_optionals:
-                # for question in self.optional_questions[self.format]:
-                    # set_question = input(f"set the {question.name} (y,*): ")
-                    # if set_question.lower() == 'y':
-                        # temp_dict = inquirer.prompt({question})
-                        # answers.update(temp_dict)
-            # after optional question handling make a update
             self.set_answers(answers)
 
 
@@ -180,55 +187,10 @@ class CommitMessage(object):
         elif self.format == "sgc":
             return False
         elif self.format == "cc":
-            return self.tag and self.header
+            logger.log("INFO", self.format)
+            cc_format_minimum_requirements:bool = self.tag and len(self.tag) > 0 and len(self.header) > 0
+            logger.log("INFO", cc_format_minimum_requirements)
+            return cc_format_minimum_requirements
         else:
             return False
     
-    
-    #TODO: this souldnt live here -> use the repository
-    def update_preselected_data(self):
-        """Update modules file
-        1 - get used module
-        2 - get modules in file (in this point this module should exist in module manager)
-        3 - search for our module inside the result
-            3.1 -  if exist update counter and last used
-            3.2 - if not exists addit to the list
-                a - limit number of modules to write to 10
-        4 - save the modules infomation
-        """
-        current_modules:list = self.module_manager.get_modules()
-        new_modules:list[ModuleConfig] = []
-        current_date = pendulum.now()
-        exist_in_module_list:bool = False
-
-        modules_as_csv = ""
-        
-        if current_modules and len(current_modules) > 0:
-            for module in current_modules:
-                if module.name.lower() == self.module.lower():
-                    module.last_used = current_date.int_timestamp
-                    module.use_count += 1
-                    exist_in_module_list = True
-                new_modules.append(module)
-        
-        if exist_in_module_list is False:
-            new_module = ModuleConfig(self.module, current_date.int_timestamp, current_date.int_timestamp, 1)
-            new_modules.append(new_module)
-
-        new_modules.sort(key=lambda module: module.last_used, reverse=True)
-
-        new_modules = new_modules[0:9:1]
-
-        for module in new_modules:
-            modules_as_csv += f"{module.name},{module.date},{module.last_used},{module.use_count}\n"
-
-        
-        # overwrite file
-        file = open(".ignore.commitcli_modules", "w")
-
-        file.write(modules_as_csv)
-        file.close()
-
-
-
-
